/* Logo Screen 16bits RGB(565) data
 *
 * ChangeLog:
 *  16-04-2003 SHARP
 */
#ifndef __initdata
#define __initdata
#endif
static int	logo_msg_width __initdata = 30;
static int	logo_msg_height __initdata = 250;
static unsigned short	logo_msg_data[30*250] __initdata ={
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x6b6d,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x4a69,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x8411,0x0861,0x0861,0x6b2d,0x9453,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0xad56,0xbdf7,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0x2966,0x0861,0x83f2,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xe6fd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x0861,0x2125,0xef3e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce3b,0xc5ba,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xce1b,0x0861,0x2945,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x4a69,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xce1b,0x9492,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xe6fc,0x18e3,0x0861,0x6b6d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xce3b,0xad75,0x0861,0x0861,0x39c7,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xc5fb,0xc5ba,0xdebc,0x9cf3,0x0861,0x0861,0x0861,0x4a69,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0xc5ba,0xce3b,0xb596,0x2945,0x0861,0x0861,0x5aeb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xc5ba,0xc5ba,0xc5ba,0xd65c,0x8431,0x18e3,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xce1b,0xc5ba,0xc5ba,0xd67c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5fb,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0xbdf7,0xad75,0x9492,0x9492,0x9492,0x9492,0x9492,0x9492,0xad75,0xbdf7,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x2945,0x7bef,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0x39a7,0x0861,0x2925,0x4229,0x6b6e,0x83f0,0x83f0,0x83f0,0x8411,0x73ae,0x4a49,0x4a69,0x0861,0x0861,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0xa4b6,0xbd79,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xce1b,0xc5f9,0xad75,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce3b,0xc5ba,0xce1b,0xbd98,0x7bd0,0x83f0,0xce3a,0xe6fd,0xe6fd,0xdedd,0xd65c,0xd65c,0xc5ba,0x0861,0x39c8,0xd65c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xffdf,0xad75,0x0861,0x0861,0x0861,0x18e3,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0x0861,0x4a29,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0x2925,0x0861,0x5acb,0x4a69,0x0861,0x4a69,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xa4b6,0x0861,0x2966,0xc5fb,0xf79e,0x2945,0x0861,0xe71c,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0x9454,0x0861,0x7b90,0xc5ba,0xd65c,0x7bef,0x0861,0xbdf7,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xc5ba,0x9cb4,0x0861,0x9492,0xce1b,0xc5ba,0x8c51,0x0861,0xbdf7,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xc5ba,0xbdb8,0x0861,0x39c7,0xdedd,0xc5ba,0x4a49,0x0861,0xbdf7,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xc5ba,0xe6fd,0x2945,0x0861,0x4229,0x6b4f,0x0861,0x0861,0x9492,0x9492,0x9492,0x6b4f,0x7b90,0x0861,0x2945,0x9492,0x9492,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xc5ba,0xce3b,0xad75,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xd65c,0xce3a,0x528b,0x0861,0x0861,0x6b6e,0x83f0,0x83f0,0x83f0,0x6b4f,0x736f,0x0861,0x2925,0x83f0,0x9492,0x7bef,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0xc5ba,0xc5ba,0x39c8,0x0861,0x39c8,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0x0861,0x39c8,0xa4b6,0x39c7,0x0861,0x5aeb,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xdebc,0x9454,0x0861,0x18c3,0xce3a,0xe6fd,0xe6fd,0xe6fd,0xe6fd,0xc5ba,0xce1b,0x0861,0x4229,0xb598,0x0861,0x18e3,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x83f1,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x4a49,0x630d,0xc5ba,0x8411,0x9492,0x5aeb,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xc5ba,0xc5fb,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0xf79e,0xc5ba,0xc5fb,0x0861,0x0861,0x0861,0xd69a,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xdedd,0xffff,0xe71d,0xe6fd,0x526a,0x6b6d,0xad75,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0xc5ba,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xdebc,0xef3e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2945,0x0861,0x18e3,0x4a69,0x9492,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xd69a,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x18e3,0x6b6d,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0x9492,0xbdf7,0xce1b,0xbd79,0x3166,0x0861,0x2925,0x8c51,0x4a69,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x9cf3,0x0861,0x8c51,0xc5ba,0xc5ba,0xbd79,0x18a3,0x0861,0x7b90,0xc5fb,0xce3b,0xad55,0x6b6d,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xe6fd,0x8431,0x0861,0xad55,0xce3b,0xc5ba,0xce1b,0x9cd4,0x0861,0x2104,0xc5ba,0xc5ba,0xef7e,0xffff,0xffff,0x5aeb,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xc5ba,0x4229,0x0861,0xd69a,0xffdf,0xc5fb,0xc5ba,0xe71d,0x39c7,0x0861,0xa4f4,0xdebc,0xffdf,0xffff,0xffff,0x18e3,0x0861,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x4a29,0x0861,0xffff,0xffff,0xef3e,0xc5ba,0xce1b,0x9cf3,0x0861,0x9492,0xffff,0xffff,0xd67c,0xb578,0x0861,0x2945,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x4a49,0x0861,0xffff,0xffff,0xffff,0xce3b,0xc5ba,0xc5f8,0x0861,0x4a69,0xffff,0xffff,0xc5fb,0x7b90,0x0861,0x6b6d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x4a69,0x0861,0xffff,0xffff,0xffff,0xe71d,0xc5ba,0xe6fd,0x0861,0x4a69,0xffff,0xf7bf,0xc5ba,0x4a4a,0x0861,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x7bef,0x0861,0xbdf7,0xffff,0xffff,0xf79e,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xe71d,0xbd79,0x0861,0x0861,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x9492,0x0861,0x9492,0xffff,0xffff,0xffff,0xc5ba,0x9453,0x0861,0x7bef,0xffff,0xd67c,0x7b90,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0xd69a,0x0861,0x2945,0xf79e,0xffff,0xffff,0xc5ba,0x41e8,0x0861,0xad75,0xffdf,0xc5ba,0x528b,0x0861,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xe6fd,0x6b6d,0x0861,0x39c7,0x9cf3,0xa4f4,0x4a2a,0x0861,0x39c7,0xffff,0xe71d,0xc5ba,0xce3b,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5ba,0xce1b,0xef5d,0x39c7,0x0861,0x0861,0x0861,0x0861,0x18c3,0xd69a,0xffff,0xdebc,0xc5ba,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdebc,0xc5ba,0xce3b,0xdebc,0x8411,0x4208,0x39c8,0x630d,0xf79e,0xffff,0xffff,0xffff,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xce3b,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5fb,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xe6fd,0xd65c,0xd65c,0xdedd,0xffdf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x18e3,0x18e3,0xad75,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x18e3,0x0861,0x0861,0x18e3,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0x734f,0x0861,0x31a7,0x39c7,0x0861,0x7bef,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xbd99,0x18a3,0x0861,0xb538,0xce79,0x0861,0x0861,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0x528b,0x0861,0x5aac,0xc5ba,0xdedd,0x7bef,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0x9474,0x0861,0x0861,0xd6bb,0xc5ba,0xc5ba,0xe71d,0x18e3,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdebc,0x2966,0x0861,0x6b6d,0xffff,0xdedd,0xc5ba,0xce3b,0xad75,0x0861,0x18e3,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0x6b4f,0x0861,0x18e3,0xf79e,0xffff,0xffdf,0xc5fb,0xc5ba,0xe6fd,0x4a69,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad16,0x0861,0x0861,0x9492,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0xc5fb,0xdedb,0x18e3,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69b,0x2104,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xce3b,0x9492,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x4a2a,0x0861,0x18c3,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5fb,0xc5ba,0xe6fd,0x4a69,0x0861,0x18e3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xce1b,0x18a3,0x0861,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xc5ba,0xd69a,0x18e3,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xa4d6,0x7bcf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xc5fb,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5fb,0xc5ba,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5fb,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xdedd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0x5aeb,0x0861,0x0861,0x39c7,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0xbdf7,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x18e3,0x0861,0x0861,0x0861,0x0861,0x0861,0x6b6d,0xffff,0xffff,0xffff,0xffff,0x9492,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0x6b2e,0x0861,0x2966,0xb578,0xdebc,0x9492,0x18e3,0x0861,0x9492,0xffff,0xf7bf,0xef7e,0x8c71,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xc5fb,0x39c8,0x0861,0xad17,0xc5ba,0xc5ba,0xdebc,0x9cf3,0x0861,0x18e3,0xf79e,0xe6fd,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0x41e8,0x0861,0x8c71,0xe6fd,0xc5fb,0xc5ba,0xe6fd,0x4a69,0x0861,0x9cf3,0xe6fd,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x8c51,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xe6fd,0x9492,0x39c7,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0x2966,0x0861,0xbd79,0xc5ba,0x6b4f,0x0861,0xb596,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0x3186,0x39c8,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0x62cd,0x0861,0x9454,0xc5ba,0x6b4f,0x0861,0xb596,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x0861,0x0861,0xffff,0xffff,0xffff,0xffff,0xce3b,0xc5ba,0x8c71,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce3b,0xd65c,0x2945,0x0861,0xf79e,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0x73ae,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0x5aeb,0x0861,0xad75,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x39a7,0x0861,0xce3a,0xc5ba,0xb596,0x9492,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0x8c71,0x0861,0x4a69,0xffff,0xffff,0xffff,0xdedd,0x9454,0x0861,0x2945,0xe6fd,0xc5ba,0xe6fc,0x39c7,0x7bef,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xce7a,0x0861,0x0861,0x9cf3,0xffff,0xffff,0xad16,0x2104,0x0861,0x9492,0xef7e,0xd69b,0x39c7,0x0861,0x18e3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xd65c,0x7bef,0x0861,0x0861,0x39c7,0x39a7,0x0861,0x0861,0x39c7,0xf79e,0xffdf,0x3186,0x0861,0x18e3,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5ba,0xc5ba,0xe71d,0x7bef,0x0861,0x0861,0x0861,0x0861,0x630c,0xf79e,0xffdf,0xce3b,0x2966,0x18c3,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0xc5ba,0xce3b,0xc5da,0x9454,0x9454,0xc5da,0xffdf,0xffff,0xce3b,0xc5ba,0xbd99,0xd6bb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xdebc,0xffdf,0xffff,0xffff,0xce3b,0xc5fb,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xef7e,0xef7e,0xffdf,0xbdf7,0xf79e,0xffff,0xffff,0xffdf,0xf7bf,0xf79e,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69a,0x18e3,0x39c7,0xf79e,0xffff,0xffff,0xffff,0x5aeb,0x39c7,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xad55,0x0861,0x0861,0x39c7,0xd69a,0xffdf,0xffdf,0x18e3,0x0861,0x18e3,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x4a69,0x4a69,0x4a69,0x4a49,0x39e8,0x41e8,0x2945,0x0861,0x0861,0x18e3,0x7bb0,0xce3b,0xd6bb,0x39c7,0x0861,0x0861,0x6b6d,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x2104,0x7bb1,0xe6fc,0x7bef,0x0861,0x0861,0x18e3,0xd69a,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xd65c,0x9cb5,0x9cb5,0x9cb5,0x9cb5,0x9c94,0x9454,0x9454,0x9474,0xad36,0x9cf3,0x2945,0x0861,0x0861,0x6b4f,0xdebc,0xbdd7,0x39c7,0x0861,0xd69a,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xce1b,0xce3a,0x4a69,0x0861,0x9454,0xc5ba,0xc5fb,0xf79e,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0xef7e,0x4a49,0x0861,0xce1b,0xc5ba,0x6b4f,0x0861,0xbdf7,0xef7e,0x738f,0x0861,0xb5b7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0xe71c,0x4a69,0x0861,0xf7bf,0xd65c,0x6b4f,0x0861,0xbdf7,0xffff,0x9492,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x9492,0x0861,0x2966,0x4a69,0x0861,0xe6fd,0xc5ba,0x8431,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0x31a7,0x0861,0x0861,0x528b,0x4a69,0x0861,0xe6fd,0xc5ba,0x8431,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69b,0x18a3,0x18c3,0x83f1,0xc5ba,0x4a69,0x0861,0xe6fd,0xc5ba,0x8431,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xce3b,0xc5ba,0xad17,0xc5d9,0xd65c,0xc5ba,0x4a69,0x0861,0xe6fd,0xc5ba,0x8431,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0x2104,0x39e8,0xe71d,0xffff,0xd65c,0xc5ba,0x4a69,0x0861,0xe6fd,0xc5ba,0x8431,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x0861,0x4a49,0xffff,0xffff,0xd65c,0xc5ba,0x4a69,0x0861,0xe6fd,0xc5ba,0x6b4f,0x0861,0x9454,0xc5ba,0x6b4f,0x0861,0xb596,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xd65c,0x0861,0x39c7,0xbdf7,0xbdf7,0x9cb5,0x9454,0x39c7,0x0861,0xad36,0x9454,0x528b,0x0861,0x9454,0xc5ba,0x6b4f,0x0861,0xb596,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xce3b,0x9493,0x4a49,0x4a49,0x4a49,0x41e8,0x39c8,0x18c3,0x0861,0x4208,0x39c8,0x2945,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0x39c8,0x0861,0xc5ba,0xc5ba,0x8431,0x0861,0xad36,0xc5ba,0x8431,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xd65c,0xd65c,0xd65c,0xd65c,0xd65c,0xc5fb,0xc5ba,0xad37,0x9cb5,0xce1b,0xc5ba,0xb596,0x9492,0xce3a,0xc5ba,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xffff,0xffff,0xe6fd,0xc5ba,0xef7e,0xffff,0xe6fd,0xc5ba,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xef7e,0xffff,0xffff,0xef7e,0xe6fd,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xbdf7,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x5aeb,0x9cf3,0xf79e,0xffff,0xffff,0xffff,0xbdf7,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69a,0x0861,0x0861,0x0861,0x4a69,0x8431,0xad17,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xad56,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x2925,0x0861,0x6b6d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x5aeb,0x39c7,0xce39,0xc5ba,0xc5ba,0x528b,0x0861,0x18c3,0x8c51,0x39a7,0x0861,0x0861,0x0861,0x0861,0x0861,0x4a69,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x4a69,0x0861,0xd69a,0xc5ba,0xc5ba,0xc5ba,0x39c8,0x0861,0x6b4f,0xce1b,0xad17,0x7bd0,0x0861,0x0861,0x0861,0x0861,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xce3b,0x0861,0x18e3,0xffff,0xdebc,0xc5ba,0xc5fb,0xbdb8,0x0861,0x2104,0xc5ba,0xc5ba,0x9454,0x0861,0x7b90,0xce59,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x0861,0x4a69,0xffff,0xffff,0xd65c,0xc5ba,0xe6fd,0x4a69,0x0861,0xbdb8,0xc5ba,0x9454,0x0861,0x6b4f,0xffdf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5fb,0x0861,0x4a69,0xffff,0xffff,0xf79e,0xc5ba,0xce1b,0x9492,0x0861,0x8431,0xc5ba,0xad36,0x0861,0x83f0,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x39c7,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xb5b7,0x0861,0x8431,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x2945,0x0861,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xad36,0x0861,0x8431,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xce3b,0x5aeb,0x0861,0xad75,0xffff,0xffff,0xef7e,0xc5ba,0x6b6e,0x0861,0x8431,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0x9cf3,0x0861,0x4a69,0xffff,0xffff,0xef7e,0xbd79,0x18c3,0x0861,0xc619,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xdedc,0x18e3,0x0861,0x6b6d,0xf79e,0xc5f9,0x2966,0x0861,0x4a69,0xef7e,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xc5ba,0xd65c,0xad75,0x0861,0x0861,0x0861,0x0861,0x0861,0x18c3,0xd69a,0xef7e,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xc5fb,0xc5ba,0xdebc,0xad55,0x39c7,0x0861,0x0861,0x4a4a,0xd69a,0xffff,0xef7e,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5fb,0xf79e,0xffff,0xffff,0xef7e,0xc5ba,0xe6fd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xce3b,0xc5ba,0xc5ba,0xd67c,0xf79e,0xffff,0xffff,0xffff,0xef7e,0xc5ba,0xe6fd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x18e3,0x18e3,0xad75,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x18e3,0x0861,0x0861,0x18e3,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0x734f,0x0861,0x31a7,0x39c7,0x0861,0x7bef,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xbd99,0x18a3,0x0861,0xb538,0xce79,0x0861,0x0861,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0x528b,0x0861,0x5aac,0xc5ba,0xdedd,0x7bef,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0x9474,0x0861,0x0861,0xd6bb,0xc5ba,0xc5ba,0xe71d,0x18e3,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdebc,0x2966,0x0861,0x6b6d,0xffff,0xdedd,0xc5ba,0xce3b,0xad75,0x0861,0x18e3,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0x6b4f,0x0861,0x18e3,0xf79e,0xffff,0xffdf,0xc5fb,0xc5ba,0xe6fd,0x4a69,0x0861,0x39c7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad16,0x0861,0x0861,0x9492,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0xc5fb,0xdedb,0x18e3,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd69b,0x2104,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xce3b,0x9492,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x4a2a,0x0861,0x18c3,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5fb,0xc5ba,0xe6fd,0x4a69,0x0861,0x18e3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xce1b,0x18a3,0x0861,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xc5ba,0xd69a,0x18e3,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xa4d6,0x7bcf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xc5fb,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5fb,0xc5ba,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5fb,0xe71d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xdedd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0x9492,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x5aeb,0x0861,0x5aeb,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xbdf7,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xf7bf,0x39c7,0x0861,0x0861,0x0861,0x2945,0x7bef,0xd69a,0xffff,0xffff,0xf7bf,0xe6fd,0xb596,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xd67c,0xb596,0x6b6d,0x18e3,0x0861,0x0861,0x0861,0x2945,0x6b6d,0x8431,0x9454,0x9cd4,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce3b,0xc5ba,0xc5ba,0xc5ba,0xce1b,0xdedd,0xa535,0x6b6d,0x18e3,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x2945,0x4a69,0x6b6d,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xdebc,0xc5fb,0xc5ba,0xc5ba,0xc5ba,0xce1b,0xdebc,0xbdb8,0x8431,0x52ab,0x2966,0x0861,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x4a29,0x526a,0x9474,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0x9c94,0x0861,0x5aec,0x8c51,0x9492,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x0861,0x0861,0x0861,0x18e3,0xf79e,0xe6fd,0xce1a,0x738f,0x9454,0xc5ba,0x9454,0x0861,0x6b4f,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0x4a4a,0x0861,0x5aab,0x4a69,0x9492,0xffff,0xffff,0xbdf7,0x0861,0x4a49,0xc5ba,0xa4f5,0x0861,0x83f0,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xc5ba,0x2104,0x0861,0xbd99,0xffff,0xffff,0xffdf,0xe6fd,0xe6fc,0x0861,0x2945,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0x0861,0x3186,0xe6fd,0xffff,0xffff,0xef7e,0xc5ba,0xd65c,0x2945,0x0861,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffdf,0xc5ba,0xce1b,0x4a69,0x0861,0xc5ba,0xad36,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xce3b,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0x4a69,0x0861,0xc5ba,0xbdb8,0x4a69,0x9cf3,0xad75,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x0861,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x18e3,0x0861,0xc5ba,0xe6fd,0xd69a,0x18e3,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0x4a69,0x0861,0xe71c,0xffff,0xffff,0xffff,0xd65c,0xad17,0x0861,0x4a49,0xd65c,0xe71d,0xce7a,0x0861,0x39c7,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0x6b6d,0x0861,0x9492,0xffff,0xffff,0xffff,0xc5fb,0xa4b6,0x39c7,0x6b6d,0xf79e,0xc5fb,0xc5ba,0xbd98,0xad75,0x5aeb,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0xad55,0x6b6d,0xd69a,0xffff,0xffff,0xf7bf,0xc5ba,0xd65c,0xffff,0xffff,0xf7bf,0xc5ba,0xce3b,0x528b,0x0861,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdebc,0xc5ba,0xe6fd,0xffff,0xffff,0xffff,0xffff,0xf79e,0xce3b,0xdebc,0xffff,0xffff,0xffff,0xf7bf,0xef3e,0x7bb0,0x39c7,0x9492,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef3e,0xdebc,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd67c,0xc5ba,0xc5ba,0xe6fd,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xce3b,0xe6fd,0xffdf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x7bef,0x4a69,0x4a69,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0x4a69,0x7bef,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71c,0x18e3,0x0861,0x0861,0x0861,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0x4209,0x0861,0x3186,0x9cd4,0x9cf3,0x18e3,0x0861,0x9cf3,0xffff,0xd65c,0xdedd,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xb538,0x0861,0x18a3,0xbd79,0xc5ba,0xd65c,0xbdf7,0x0861,0x2945,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0x6b4f,0x0861,0x8411,0xe71d,0xc5fb,0xc5ba,0xe71d,0x2945,0x0861,0xe71c,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xc5ba,0x528b,0x0861,0xbdf7,0xffff,0xef7e,0xc5ba,0xce1b,0x7bef,0x0861,0xbdf7,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x4229,0x0861,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0x8c51,0x0861,0xbdf7,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdebc,0xc5ba,0x4a49,0x0861,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0x632d,0x0861,0xbdf7,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x4a69,0x0861,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x2945,0x0861,0xf79e,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x4a69,0x0861,0xd69a,0xffff,0xffff,0xdebc,0x9454,0x0861,0x39c7,0xffff,0xc5ba,0xd65c,0x0861,0x2945,0x5aeb,0x18e3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x7bef,0x0861,0xad75,0xffff,0xffff,0xce1b,0x39c8,0x0861,0x9492,0xffff,0x83f2,0x4a4a,0x0861,0x0861,0x0861,0x0861,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xc5ba,0x8c51,0x0861,0x6b6d,0xffff,0xef7e,0x9454,0x0861,0x0861,0x7bef,0x2945,0x0861,0x0861,0x0861,0x18c3,0x9492,0xbdf7,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xdedd,0xc5ba,0xc5f8,0x4a69,0x7bef,0xffff,0xc5fa,0x2104,0x0861,0x0861,0x0861,0x0861,0x18a3,0x62cd,0x0861,0x39c8,0xef7e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xdebc,0xffff,0xffff,0xef7e,0xa4b6,0x0861,0x0861,0x0861,0x2104,0x7b90,0xc5ba,0xc5fb,0x0861,0x4a49,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xd65c,0xdedd,0xffff,0xffdf,0xce1b,0xc5ba,0x39c8,0x2104,0x7b90,0xc5fb,0xdedd,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xc5ba,0xc5ba,0xc5ba,0xce1b,0xe71d,0xffff,0xffff,0xc5ba,0xd65c,0x0861,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xd65c,0xce1b,0xe71d,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0xbdf7,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xd65c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xbdf7,0x9492,0x6b6d,0x4a69,0x4a69,0x4a69,0x4a69,0x4a69,0x9492,0x9492,0xad75,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x6b6d,0x18e3,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x18e3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x39c7,0x0861,0x0861,0x2125,0x5acc,0x7b90,0x9cb5,0x9cb5,0x9cb5,0xad36,0x83f0,0x8411,0x4a69,0x4a69,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0x7bd0,0x0861,0x2966,0x9454,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xc5fb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xce3b,0x6b4f,0x0861,0x5aab,0xce3b,0xe6fd,0xef7e,0xef7e,0xef7e,0xef7e,0xe6fd,0xe6fd,0xd65c,0xd65c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0x83f1,0x0861,0x0861,0x0861,0x5aeb,0x9cf3,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xdebc,0x8c71,0x0861,0x0861,0x0861,0x6b6d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xc5ba,0xc5ba,0xc5ba,0xce1a,0x8410,0x4a69,0xd69a,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe6fd,0xc5ba,0xc5ba,0xc5ba,0xdebc,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xe6fd,0xd65c,0xf79e,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0x9492,0x18e3,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xad75,0x6b6d,0x18e3,0x0861,0x0861,0x9492,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf79e,0xbdf7,0xbdf7,0x9492,0x7bef,0x4a69,0x0861,0x0861,0x0861,0x0861,0x18e3,0x6b6d,0xe71c,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xbdf7,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x0861,0x2966,0x7b90,0xd69b,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffdf,0xef7e,0xef7e,0x0861,0x0861,0x18c3,0x39c8,0x62cd,0x83f2,0xbd79,0xc5fb,0xdebc,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xef7e,0xc5ba,0xc5ba,0xad17,0xc5ba,0xc5ba,0xc5ba,0xc5ba,0xce3b,0xe71d,0xffdf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xc5ba,0xc5ba,0xc5fb,0xd65c,0xdedd,0xef3e,0xffdf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x8c51,0x7bef,0x7bef,0xef7d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xe6dd,0xe6dd,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0x8c71,0x7bef,0x7bef,0xef7d,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xe71d,0xe6dd,0xe6dd,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0x2104,0x0000,0x0000,0xdefb,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xce1b,0xc5ba,0xc5ba,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xf7bf,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,0xffff,
	};
